@@ -169,7 +169,7 @@ def sync(obj, name, service_id, remote=None):
         click.echo('\nRécupération du fichier emediaplace')
         fileheader = CONFIG['EMEDIAPLACE']['fileheader']
         today = time.strftime('%Y%m%d')
-        filename = '{0}_{1}_ctv5.ts'.format(fileheader, today)
+        filename = '{0}_{1}.ts'.format(fileheader, today)
         media.sync_file(filename)
     else:
         result = media.sync_file(name, remote=remote)
