@@ -436,7 +436,7 @@ def embed_image_in_tsfile(**kwargs):
 def sync_file(name=None, remote=None):
     """Cette fonction synchronise les fichiers depuis les serveurs pairs"""
     if name.startswith('revue_emediaplace'):
-        tsfile = Media(name)
+        tsfile = Media(name.replace('.ts', '_ctv5.ts'))
         # récupère le fichier emediaplace
         ftp_server = CONFIG['EMEDIAPLACE']['ftp_server']
         ftp_user = CONFIG['EMEDIAPLACE']['ftp_user']
