@@ -7,8 +7,6 @@ from systemd import journal
 from .consts import CONFIG
 from .consts import INFOS
 from .consts import PROGRAMS
-from . import cluster
-from . import media
 from .streaming import dtplay, vlc
 
 import collections
@@ -131,6 +129,7 @@ class Program(object):
         Les informations sur les synopsis des films sont dans
         une base de données.
         """
+        from .media import Media
         xml = {
             'BroadcastData': {
                 'ProviderInfo': {
@@ -160,7 +159,7 @@ class Program(object):
                         '%d/%m/%Y %H:%M:%S'
                         )
                 filename = filename.split('/')[-1].split(':')[0]
-                tsfile = media.Media(filename)
+                tsfile = Media(filename)
                 info = tsfile.details()
                 if not info:
                     name = filename.replace('.ts', '')
@@ -232,6 +231,7 @@ class Program(object):
 
     def check(self):
         """Routine de vérification de la cohérence d'un programme"""
+        from .media import Media
         answer = {
             'redis': None,
             'program': None,
@@ -279,14 +279,14 @@ class Program(object):
                 # avant la limite
                 last_program = infos[timestamps[-1]]
                 last_media = last_program.split(':')[0].split('/')[-1]
-                overflow = media.Media(last_media).duration + timestamps[-1]
+                overflow = Media(last_media).duration + timestamps[-1]
                 if overflow >= self.limit:
                     answer['overflow'] = overflow
                 files = []
                 for timestamp, path in infos.items():
                     filepath = path.split(':')[0]
                     filename = filepath.split('/')[-1]
-                    if not media.Media(filename).exists:
+                    if not Media(filename).exists:
                         files.append(filename)
                 if files:
                     answer['program'] = files
@@ -319,6 +319,8 @@ class Program(object):
         Requiert que tous les serveurs REDIS de chaque serveur du cluster
         soient accessibles à distance.
         """
+        from .media import Media
+        from .cluster import Server
         self_status = INFOS.get('status').decode('utf-8')
         if self_status == 'master':
             journal.send(
@@ -331,11 +333,11 @@ class Program(object):
         elif self_status == 'slave':
             if not remote:
                 # on synchronise par défaut avec le master du cluster
-                server = cluster.Server().get_master()
+                server = Server().get_master()
                 if not server:
                     raise SystemError("Aucun serveur master dans le cluster")
             else:
-                server = cluster.Server(remote)
+                server = Server(remote)
             # on synchronise avec 'server'
             # en gros, on le fait à la bourrin: on écrase le local
             PROGRAMS.delete(self.redis_zset_key)
@@ -354,7 +356,7 @@ class Program(object):
             for path, timestamp in infos.items():
                 filepath, index = path.split(':')
                 filename = filepath.split('/')[-1]
-                m = media.Media(filename)
+                m = Media(filename)
                 PROGRAMS.zadd(
                     self.redis_zset_key,
                     '{}:{}'.format(m.filepath, index),
